/**
 * 
 */
package com.as.lyons.wcf.svc.atm;

import java.util.Iterator;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import javax.xml.soap.Detail;
import javax.xml.soap.DetailEntry;
import javax.xml.soap.SOAPFault;

import org.slf4j.helpers.MessageFormatter;
import org.springframework.util.Assert;

import com.as.lyons.wcf.svc.atm.client.ErrorResult;
import com.as.lyons.wcf.svc.atm.client.IATMService;
import com.as.lyons.wcf.svc.atm.client.LogonResult;
import com.sun.xml.ws.fault.ServerSOAPFaultException;

/**
 * @author pgurov
 *
 */
public abstract class AbstractAtmServiceCall implements AtmServiceCall {

	private static Class<?>[] errorClasses = new Class[] { ErrorResult.class };

	protected void handleError(String msg, String errorMessage, boolean rethrow) throws StopProcesingException {
		String resMsg = MessageFormatter.arrayFormat("{}{}{}", new String[] { msg, errorMessage == null ? " - " : ": ",
				errorMessage == null ? "got a SOAP exception" : errorMessage }).getMessage();
		System.out.println(resMsg);
		if (rethrow) {
			throw new StopProcesingException();
		}
	}

	protected void message(String template, Object... args) {
		String msg = MessageFormatter.arrayFormat(template, args).getMessage();
		System.out.println(msg);
	}

	protected String login(IATMService svc, LogonProperties loginProps) throws StopProcesingException {
		String token = null;
		try {
			LogonResult resObj = svc.logon(loginProps.getCompanyId(), loginProps.getUserName(),
					loginProps.getPassword());
			Assert.notNull(resObj, "The returned LogonResult is null");
			token = resObj.getToken();
			Assert.notNull(token, "The returned token is null");
		} catch (ServerSOAPFaultException ex) {
			handleFault("\nError logging on to IATMService", ex, true);
		} catch (Exception e) {
			handleError("\nError communicating to the IATMService", e.getMessage(), true);
		}
		return token;
	}

	protected void logoff(IATMService svc, String token) {
		try {
			svc.logoff(token);
		} catch (Exception e) {
			// swallowing the exception
		}
	}

	@SuppressWarnings("rawtypes")
	protected void handleFault(String msg, ServerSOAPFaultException ex, boolean rethrow) throws StopProcesingException {
		String res = null;
		SOAPFault fault = ex.getFault();
		if (fault != null) {
			Detail det = fault.getDetail();
			if (det != null) {
				Iterator resItr = det.getDetailEntries();
				if (resItr != null && resItr.hasNext()) {
					DetailEntry de = (DetailEntry) resItr.next();
					if (de != null) {
						try {
							JAXBContext ctx = JAXBContext.newInstance(errorClasses);
							Unmarshaller u = ctx.createUnmarshaller();
							JAXBElement<ErrorResult> resEl = u.unmarshal(de, ErrorResult.class);
							ErrorResult resO = resEl.getValue();
							res = resO.getErrorMessage();
						} catch (JAXBException e) {
						}
					}
				}
			}
		}
		handleError(msg, res, rethrow);
	}

}
