/**
 * 
 */
package com.as.lyons.wcf.svc.atm;

import com.as.lyons.wcf.svc.atm.client.IATMService;
import com.as.lyons.wcf.svc.atm.client.StatusDescriptionResult;
import com.sun.xml.ws.fault.ServerSOAPFaultException;

/**
 * @author pgurov
 *
 */
public class DescribeStatusCodeServiceCall extends AbstractAtmServiceCall {

	@Override
	public void printHelp(LogonProperties loginProps, String method) {
		StringBuilder sb = new StringBuilder(500).append("Use:\n\t").append(loginProps.getAppStartCommand());
		sb.append(method).append(" <an integer status code>");
		System.out.println(sb.toString());
	}

	@Override
	public void call(IATMService svc, LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		int statusCode = validateRequest(loginProps, method, args);
		String token = login(svc, loginProps);
		StatusDescriptionResult res = null;
		try {
			res = svc.describeStatusCode(token, statusCode);
		} catch (ServerSOAPFaultException ex) {
			handleFault("\nError calling " + method + " on the ATM service 1", ex, false);
		} catch (Exception e) {
			handleError("\nError calling " + method + " on the ATM service 2", e.getMessage(), false);
		}
		reportResult(method, res);
		logoff(svc, token);
	}

	private void reportResult(String method, StatusDescriptionResult res) {
		if (res == null) {
			message("The ATM {} call did not return a response - this is an error!", method);
		} else {
			message("The ATM {} returned the following status description: {}", method, res.getStatusDescription());
		}
	}

	private int validateRequest(LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		if (args == null || args.length == 0) {
			printHelp(loginProps, method);
			throw new StopProcesingException();
		}
		int statusCode = 0;
		try {
			statusCode = Integer.parseInt(args[0]);
		} catch (Exception e) {
			printHelp(loginProps, method);
			throw new StopProcesingException();
		}
		return statusCode;
	}

}
