/**
 * 
 */
package com.as.lyons.wcf.svc.atm;

import com.as.lyons.wcf.svc.atm.client.BooleanResult;
import com.as.lyons.wcf.svc.atm.client.IATMService;
import com.sun.xml.ws.fault.ServerSOAPFaultException;

/**
 * @author pgurov
 *
 */
public class IsParticipantServiceCall extends AbstractAtmServiceCall {

	@Override
	public void printHelp(LogonProperties loginProps, String method) {
		StringBuilder sb = new StringBuilder(500).append("Use:\n\t").append(loginProps.getAppStartCommand());
		sb.append(method).append(" <aba>");
		System.out.println(sb.toString());
	}

	@Override
	public void call(IATMService svc, LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		validateRequest(loginProps, method, args);
		String token = login(svc, loginProps);
		BooleanResult res = null;
		try {
			res = svc.isParticipant(token, args[0]);
		} catch (ServerSOAPFaultException ex) {
			handleFault("\nError calling " + method + " on the ATM service 1", ex, false);
		} catch (Exception e) {
			handleError("\nError calling " + method + " on the ATM service 2", e.getMessage(), false);
		}
		reportResult(method, res);
		logoff(svc, token);
	}

	private void reportResult(String method, BooleanResult res) {
		if (res == null) {
			message("The ATM {} call did not return a response - this is an error!", method);
		} else {
			message("The ATM {} - the provided ABA is {}participant", method, res.isValue() ? "" : "not ");
		}
	}

	private void validateRequest(LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		if (args == null || args.length == 0) {
			printHelp(loginProps, method);
			throw new StopProcesingException();
		}
	}

}
