/**
 * 
 */
package com.as.lyons.wcf.svc.atm;

import com.as.lyons.wcf.svc.atm.client.DetailedStatusCodeResult;
import com.as.lyons.wcf.svc.atm.client.IATMService;
import com.as.lyons.wcf.svc.atm.client.InstitutionAddress;
import com.sun.xml.ws.fault.ServerSOAPFaultException;

/**
 * @author pgurov
 *
 */
public class VerifyAccountWithDetailsServiceCall extends AbstractAtmServiceCall {

	@Override
	public void printHelp(LogonProperties loginProps, String method) {
		StringBuilder sb = new StringBuilder(500).append("Use:\n\t").append(loginProps.getAppStartCommand());
		sb.append(method).append(" <aba> <account number> <amount e.g. 123.12> ")
				.append("<customer present flag: 0|1> <deny NSF flag: 0|1>");
		System.out.println(sb.toString());
	}

	@Override
	public void call(IATMService svc, LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		validateRequest(loginProps, method, args);
		String token = login(svc, loginProps);
		DetailedStatusCodeResult res = null;
		try {
			res = svc.verifyAccountWithDetails(token, args[0], args[1], args[2], args[3], args[4]);
		} catch (ServerSOAPFaultException ex) {
			handleFault("\nError calling " + method + " on the ATM service 1", ex, false);
		} catch (Exception e) {
			handleError("\nError calling " + method + " on the ATM service 2", e.getMessage(), false);
		}
		reportResult(method, res);
		logoff(svc, token);
	}

	private void reportResult(String method, DetailedStatusCodeResult res) {
		if (res == null) {
			message("The ATM {} call did not return a response - this is an error!", method);
		} else {
			InstitutionAddress fi = res.getPrimaryInstitution();
			if (fi == null) {
				// this is generally an error, but for the test
				fi = new InstitutionAddress();
			}
			message("The ATM {} call returned status code: {}; and FI: {} of {} {}", method, res.getStatusCode(),
					fi.getName(), fi.getCity(), fi.getState());
		}
	}

	private void validateRequest(LogonProperties loginProps, String method, String[] args)
			throws StopProcesingException {
		if (args == null || args.length < 5) {
			printHelp(loginProps, method);
			throw new StopProcesingException();
		}
	}

}
